#!/usr/bin/env python

"""
BaseHTTPRequestHandler adapter.
"""

import WebStack.BaseHTTPRequestHandler
import BaseHTTPServer

class HandlerFactory:

    "A factory class creating WebStack dispatcher objects."

    def __init__(self, resource):

        "Initialise the root application-specific 'resource'."

        self.webstack_resource = resource

    def __call__(self, request, client_address, server):

        "Act as a factory for the server objects."

        handler = Handler(request, client_address, server, self.webstack_resource)
        return handler

class Handler(BaseHTTPServer.BaseHTTPRequestHandler):

    "A class dispatching requests to WebStack resources."

    def __init__(self, request, client_address, server, resource):

        "Initialise the root application-specific 'resource'."

        self.webstack_resource = resource
        BaseHTTPServer.BaseHTTPRequestHandler.__init__(self, request, client_address, server)

    def handle(self):

        "Dispatch the request to the root application-specific resource."

        # NOTE: Overriding and trimming back the method's functionality.

        self.raw_requestline = self.rfile.readline()
        if not self.parse_request(): # An error code has been sent, just exit
            return

        trans = WebStack.BaseHTTPRequestHandler.Transaction(self)
        self.webstack_resource.respond(trans)
        trans.commit()

# vim: tabstop=4 expandtab shiftwidth=4
